@@ -1,17 +1,17 @@
 
-print.bayes_mean_scale_pred <- function(x, ...){
+print.bayesmeanscale_pred <- function(x, ...){
   
   print(x$predTable, row.names=F, ...)
   
 }
 
-print.bayes_mean_scale_marg <- function(x, ...){
+print.bayesmeanscale_marg <- function(x, ...){
   
   print(x$diffTable, row.names=F, ...)
   
 }
 
-print.bayes_mean_scale_marg_compare <- function(x, ...){
+print.bayesmeanscale_margcompare <- function(x, ...){
   
   print(x$diffTable, row.names=F, ...)
   
